@@ -147,7 +147,7 @@ static int do_init_client_dh(struct keyexchange_algorithm *c,
 
   /* FIXME: Use this value to choose a verifier function */
   if (hostkey_algorithm_atom != ATOM_SSH_DSS 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
       && hostkey_algorithm_atom != ATOM_SSH_DSS_KLUDGE
 #endif
       )
