@@ -187,7 +187,7 @@ do_dsa_sign(struct signer *c,
   return signature;
 }
 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
 static struct lsh_string *do_dsa_sign_kludge(struct signer *c,
 					     UINT32 msg_length,
 					     UINT8 *msg)
@@ -223,7 +223,7 @@ struct signer *make_dsa_signer_kludge(struct signer *s)
   self->dsa = dsa;
   return &self->super;
 }
-#endif /* DATAFELLOWS_SSH2_SSH_DSA_KLUDGE */
+#endif /* DATAFELLOWS_WORKAROUNDS */
 
 #if WITH_DSA_CLASSIC
 /* Uses the (better) format from an obsoleted draft */
@@ -375,7 +375,7 @@ static int do_dsa_verify(struct verifier *c,
   return res;
 }
 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
 static int do_dsa_verify_kludge(struct verifier *c,
 				UINT32 length,
 				UINT8 *msg,
@@ -418,7 +418,7 @@ struct verifier *make_dsa_verifier_kludge(struct verifier *v)
   self->dsa = dsa;
   return &self->super;
 }
-#endif /* DATAFELLOWS_SSH2_SSH_DSA_KLUDGE */
+#endif /* DATAFELLOWS_WORKAROUNDS */
      
 #if WITH_DSA_CLASSIC
 static int do_dsa_verify_classic(struct verifier *c,
@@ -473,9 +473,14 @@ struct verifier *make_dsa_verifier_classic(struct verifier *v)
 }
 #endif /* WITH_DSA_CLASSIC */
 
-static int parse_dsa_public(struct simple_buffer *buffer,
-			    struct dsa_public *public)
+int parse_dsa_public(struct simple_buffer *buffer,
+		     struct dsa_public *public)
 {
+  mpz_init(public->p);
+  mpz_init(public->q);
+  mpz_init(public->g);
+  mpz_init(public->y);
+
   return (parse_bignum(buffer, public->p)
 	  && (mpz_sgn(public->p) == 1)
 	  && parse_bignum(buffer, public->q)
@@ -506,10 +511,6 @@ static struct signer *make_dsa_signer(struct signature_algorithm *c,
 
   /* FIXME: The allocator could do this kind of initialization
    * automatically. */
-  mpz_init(res->public.p);
-  mpz_init(res->public.q);
-  mpz_init(res->public.g);
-  mpz_init(res->public.y);
   mpz_init(res->a);
   
   simple_buffer_init(&public_buffer, public_length, public);
@@ -583,7 +584,7 @@ struct signature_algorithm *make_dsa_algorithm(struct randomness *random)
   return &dsa->super;
 }
 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
 
 /* FIXME: name clash, by convention this should have been
    make_dsa_verifier_kludge, but it has already been used above */
