@@ -194,18 +194,6 @@ int disconnect_kex_failed(struct ssh_connection *connection, const char *msg)
 				   msg, ""));
 }
 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
-/* FIXME: A more general handling of workarounds and version numbers 
- * would be needed */
-
-int invoke_ssh2_dsa_kludge_p(struct lsh_string *s)
-{
-  /* FIXME: Improve the version string test. */
-  return( (s->length >= 15)
-	  && !memcmp(s->data, "SSH-1.99-2.0.13", 15));
-}
-#endif DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
-
 static int do_handle_kexinit(struct packet_handler *c,
 			     struct ssh_connection *connection,
 			     struct lsh_string *packet)
@@ -279,9 +267,9 @@ static int do_handle_kexinit(struct packet_handler *c,
     = select_algorithm(connection->kexinits[0]->server_hostkey_algorithms,
 		       connection->kexinits[1]->server_hostkey_algorithms);
 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
   if ( (hostkey_algorithm == ATOM_SSH_DSS)
-       && invoke_ssh2_dsa_kludge_p(connection->versions[!closure->type]))
+       && connection->peer_flags & PEER_SSH_DSS_KLUDGE)
     {
       hostkey_algorithm = ATOM_SSH_DSS_KLUDGE;
     }
