@@ -266,9 +266,11 @@ int main(int argc, char **argv)
 
   /* No randomness is needed for verifying signatures */
   lookup_table = make_alist(1
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
 			    +1,
 			    ATOM_SSH_DSS_KLUDGE, make_fake_host_db(make_dsa_kludge_algorithm(NULL)),
+#else
+			    ,
 #endif
 			    ATOM_SSH_DSS, make_fake_host_db(make_dsa_algorithm(NULL)),
 			    -1); 
