@@ -41,6 +41,7 @@
 #include "reaper.h"
 #include "server.h"
 #include "server_keyexchange.h"
+#include "server_authorization.h"
 #include "sexp.h"
 #include "ssh.h"
 #include "tcpforward_commands.h"
@@ -98,33 +99,6 @@ void usage(void)
   exit(1);
 }
 
-/* GABA:
-   (class
-     (name fake_authorization_db)
-     (super lookup_verifier)
-     (vars
-       (algorithm object signature_algorithm)))
-*/
-
-static struct verifier *do_key_lookup(struct lookup_verifier *c,
-				      struct lsh_string *keyholder UNUSED,
-				      struct lsh_string *key)
-{
-  CAST(fake_authorization_db, closure, c);
-
-  return MAKE_VERIFIER(closure->algorithm, key->length, key->data);
-}
-
-static struct lookup_verifier *make_fake_authorization_db(struct signature_algorithm *a)
-{
-  NEW(fake_authorization_db, res);
-
-  res->super.lookup = do_key_lookup;
-  res->algorithm = a;
-
-  return &res->super;
-}
-
 /* FIXME: We should have some more general functions for reading
  * private keys. */
 
@@ -205,7 +179,7 @@ static int do_read_key(struct sexp_handler *h, struct sexp *private)
 	  ALIST_SET(closure->keys, ATOM_SSH_DSS,
 		    make_keypair_info(public, private));
 
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
 	  ALIST_SET(closure->keys, ATOM_SSH_DSS_KLUDGE,
 		    make_keypair_info(public,
 				      make_dsa_signer_kludge(private)));
@@ -481,14 +455,14 @@ int main(int argc, char **argv)
   kex = make_dh_server(dh, keys);
 
   authorization_lookup = make_alist(1
-#if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
+#if DATAFELLOWS_WORKAROUNDS
 				    +1,
-				    ATOM_SSH_DSS_KLUDGE, make_fake_authorization_db(make_dsa_kludge_algorithm(NULL)),
+				    ATOM_SSH_DSS_KLUDGE, make_authorization_db(make_dsa_kludge_algorithm(NULL), &md5_algorithm),
 #else
 				    ,
 #endif
 
-				    ATOM_SSH_DSS, make_fake_authorization_db(make_dsa_algorithm(NULL)),
+				    ATOM_SSH_DSS, make_authorization_db(make_dsa_algorithm(NULL), &md5_algorithm),
 
 				    -1);
 
